@@ -1,16 +1,19 @@
 ## Inspired by Rails' and Airbrake's backtrace parsers.
 
 module Raven
-
   # Front end to parsing the backtrace for each notice
   class Backtrace
     # Handles backtrace parsing line by line
     class Line
-      # regexp (optionnally allowing leading X: for windows support)
-      RUBY_INPUT_FORMAT = %r{^((?:[a-zA-Z]:)?[^:]+|<.*>):(\d+)(?::in `([^']+)')?$}
+      # regexp (optional leading X: on windows, or JRuby9000 class-prefix)
+      RUBY_INPUT_FORMAT = /
+        ^ \s* (?: [a-zA-Z]: | uri:classloader: )? ([^:]+ | <.*>):
+        (\d+)
+        (?: :in \s `([^']+)')?$
+      /x
 
       # org.jruby.runtime.callsite.CachingCallSite.call(CachingCallSite.java:170)
-      JAVA_INPUT_FORMAT = %r{^(.+)\.([^\.]+)\(([^\:]+)\:(\d+)\)$}
+      JAVA_INPUT_FORMAT = /^(.+)\.([^\.]+)\(([^\:]+)\:(\d+)\)$/
 
       # The file portion of the line (such as app/models/user.rb)
       attr_reader :file
@@ -31,6 +34,7 @@ module Raven
         ruby_match = unparsed_line.match(RUBY_INPUT_FORMAT)
         if ruby_match
           _, file, number, method = ruby_match.to_a
+          file.sub!(/\.class$/, ".rb")
           module_name = nil
         else
           java_match = unparsed_line.match(JAVA_INPUT_FORMAT)
@@ -47,7 +51,7 @@ module Raven
       end
 
       def in_app
-        if self.file =~ self.class.in_app_pattern
+        if file =~ self.class.in_app_pattern
           true
         else
           false
