@@ -1,4 +1,5 @@
 require 'spec_helper'
+require 'raven/integrations/rack'
 
 describe Raven::Event do
   before do
@@ -51,7 +52,7 @@ describe Raven::Event do
     end
 
     it 'has extra data' do
-      expect(hash[:extra]).to eq('my_custom_variable' => 'value')
+      expect(hash[:extra]["my_custom_variable"]).to eq('value')
     end
 
     it 'has platform' do
@@ -59,15 +60,15 @@ describe Raven::Event do
     end
 
     it 'has SDK' do
-      expect(hash[:sdk]).to eq("name" => "sentry-raven", "version" => Raven::VERSION)
+      expect(hash[:sdk]).to eq("name" => "raven-ruby", "version" => Raven::VERSION)
     end
 
-    it 'has os' do
-      expect(hash[:contexts][:os].keys).to eq(%w(name version build kernel_version))
+    it 'has server os' do
+      expect(hash[:extra][:server][:os].keys).to eq([:name, :version, :build, :kernel_version])
     end
 
     it 'has runtime' do
-      expect(hash[:contexts][:runtime]["version"]).to match(/ruby/)
+      expect(hash[:extra][:server][:runtime][:version]).to match(/ruby/)
     end
   end
 
@@ -128,8 +129,8 @@ describe Raven::Event do
     end
 
     it "merges extra data" do
-      expect(hash[:extra]).to eq('key' => 'value',
-                                 'my_custom_variable' => 'value')
+      expect(hash[:extra]['key']).to eq('value')
+      expect(hash[:extra]['my_custom_variable']).to eq('value')
     end
   end
 
@@ -192,6 +193,8 @@ describe Raven::Event do
     let(:hash) do
       config = Raven::Configuration.new
       config.tags = { 'key' => 'value' }
+      config.release = "custom"
+      config.current_environment = "custom"
 
       Raven::Event.new(
         :level => 'warning',
@@ -207,12 +210,15 @@ describe Raven::Event do
     it 'merges tags data' do
       expect(hash[:tags]).to eq('key' => 'value',
                                 'foo' => 'bar')
+      expect(hash[:release]).to eq("custom")
+      expect(hash[:environment]).to eq("custom")
     end
   end
 
   context 'configuration tags unspecified' do
     it 'should not persist tags between unrelated events' do
       config = Raven::Configuration.new
+      config.logger = Logger.new(nil)
 
       Raven::Event.new(
         :level => 'warning',
@@ -238,6 +244,7 @@ describe Raven::Event do
   context 'tags hierarchy respected' do
     let(:hash) do
       config = Raven::Configuration.new
+      config.logger = Logger.new(nil)
       config.tags = {
         'configuration_context_event_key' => 'configuration_value',
         'configuration_context_key' => 'configuration_value',
@@ -309,9 +316,9 @@ describe Raven::Event do
     end
 
     it 'prioritizes event context over request context' do
-      expect(hash[:extra]).to eq('context_event_key' => 'event_value',
-                                 'context_key' => 'context_value',
-                                 'event_key' => 'event_value')
+      expect(hash[:extra]['context_event_key']).to eq('event_value')
+      expect(hash[:extra]['context_key']).to eq('context_value')
+      expect(hash[:extra]['event_key']).to eq('event_value')
     end
   end
 
@@ -333,19 +340,9 @@ describe Raven::Event do
     end
 
     it 'prioritizes event context over request context' do
-      expect(hash[:extra]).to eq('context_event_key' => 'event_value',
-                                 'context_key' => 'context_value',
-                                 'event_key' => 'event_value')
-    end
-  end
-
-  describe '.initialize' do
-    it 'should not touch the env object for an ignored environment' do
-      Raven.configure do |config|
-        config.current_environment = 'test'
-      end
-      Raven.rack_context({})
-      Raven::Event.new
+      expect(hash[:extra]['context_event_key']).to eq('event_value')
+      expect(hash[:extra]['context_key']).to eq('context_value')
+      expect(hash[:extra]['event_key']).to eq('event_value')
     end
   end
 
@@ -461,21 +458,74 @@ describe Raven::Event do
       module Raven::Test
         class BaseExc < RuntimeError; end
         class SubExc < BaseExc; end
+        module ExcTag; end
+      end
+      let(:config) do
+        config = Raven::Configuration.new
+        config.logger = Logger.new(nil)
+        config
       end
 
-      it 'returns nil for a string match' do
-        config = Raven::Configuration.new
-        config.excluded_exceptions << 'Raven::Test::BaseExc'
-        expect(Raven::Event.capture_exception(Raven::Test::BaseExc.new,
-                                              :configuration => config)).to be_nil
+      context "invalid exclusion type" do
+        it 'returns Raven::Event' do
+          config.excluded_exceptions << nil
+          config.excluded_exceptions << 1
+          config.excluded_exceptions << {}
+          expect(Raven::Event.capture_exception(Raven::Test::BaseExc.new,
+                                                :configuration => config)).to be_a(Raven::Event)
+        end
       end
 
-      it 'returns nil for a class match' do
-        config = Raven::Configuration.new
-        config.excluded_exceptions << Raven::Test::BaseExc
+      context "defined by string type" do
+        it 'returns nil for a class match' do
+          config.excluded_exceptions << 'Raven::Test::BaseExc'
+          expect(Raven::Event.capture_exception(Raven::Test::BaseExc.new,
+                                                :configuration => config)).to be_nil
+        end
 
-        expect(Raven::Event.capture_exception(Raven::Test::SubExc.new,
-                                              :configuration => config)).to be_nil
+        it 'returns nil for a top class match' do
+          config.excluded_exceptions << '::Raven::Test::BaseExc'
+          expect(Raven::Event.capture_exception(Raven::Test::BaseExc.new,
+                                                :configuration => config)).to be_nil
+        end
+
+        it 'returns nil for a sub class match' do
+          config.excluded_exceptions << 'Raven::Test::BaseExc'
+          expect(Raven::Event.capture_exception(Raven::Test::SubExc.new,
+                                                :configuration => config)).to be_nil
+        end
+
+        it 'returns nil for a tagged class match' do
+          config.excluded_exceptions << 'Raven::Test::ExcTag'
+          expect(Raven::Event.capture_exception(Raven::Test::SubExc.new.tap { |x| x.extend(Raven::Test::ExcTag) },
+                                                :configuration => config)).to be_nil
+        end
+
+        it 'returns Raven::Event for an undefined exception class' do
+          config.excluded_exceptions << 'Raven::Test::NonExistentExc'
+          expect(Raven::Event.capture_exception(Raven::Test::BaseExc.new,
+                                                :configuration => config)).to be_a(Raven::Event)
+        end
+      end
+
+      context "defined by class type" do
+        it 'returns nil for a class match' do
+          config.excluded_exceptions << Raven::Test::BaseExc
+          expect(Raven::Event.capture_exception(Raven::Test::BaseExc.new,
+                                                :configuration => config)).to be_nil
+        end
+
+        it 'returns nil for a sub class match' do
+          config.excluded_exceptions << Raven::Test::BaseExc
+          expect(Raven::Event.capture_exception(Raven::Test::SubExc.new,
+                                                :configuration => config)).to be_nil
+        end
+
+        it 'returns nil for a tagged class match' do
+          config.excluded_exceptions << Raven::Test::ExcTag
+          expect(Raven::Event.capture_exception(Raven::Test::SubExc.new.tap { |x| x.extend(Raven::Test::ExcTag) },
+                                                :configuration => config)).to be_nil
+        end
       end
     end
 
@@ -580,6 +630,14 @@ describe Raven::Event do
       end
     end
 
+    describe "#get_file_context" do
+      it "delegates to the linecache" do
+        expect(subject.linecache).to receive(:get_file_context)
+
+        subject.get_file_context("this", 2, 10)
+      end
+    end
+
     it 'accepts an options hash' do
       expect(Raven::Event.capture_exception(exception, :logger => 'logger').logger).to eq('logger')
     end
